# The Block Editor’s Data

Namespace: `core/block-editor`.

## Selectors

<!-- START TOKEN(Autogenerated selectors|../../../packages/block-editor/src/store/selectors.js) -->

### areInnerBlocksControlled

Checks if a given block has controlled inner blocks.

_Parameters_

-   _state_ `Object`: Global application state.
-   _clientId_ `string`: The block to check.

_Returns_

-   `boolean`: True if the block has controlled inner blocks.

### canInsertBlocks

Determines if the given blocks are allowed to be inserted into the block
list.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientIds_ `string`: The block client IDs to be inserted.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `boolean`: Whether the given blocks are allowed to be inserted.

### canInsertBlockType

Determines if the given block type is allowed to be inserted into the block list.

_Parameters_

-   _state_ `Object`: Editor state.
-   _blockName_ `string`: The name of the block type, e.g.' core/paragraph'.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `boolean`: Whether the given block type is allowed to be inserted.

### canMoveBlock

Determines if the given block is allowed to be moved.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: The block client Id.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `boolean`: Whether the given block is allowed to be moved.

### canMoveBlocks

Determines if the given blocks are allowed to be moved.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientIds_ `string`: The block client IDs to be moved.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `boolean`: Whether the given blocks are allowed to be moved.

### canRemoveBlock

Determines if the given block is allowed to be deleted.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: The block client Id.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `boolean`: Whether the given block is allowed to be removed.

### canRemoveBlocks

Determines if the given blocks are allowed to be removed.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientIds_ `string`: The block client IDs to be removed.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `boolean`: Whether the given blocks are allowed to be removed.

### didAutomaticChange

Returns true if the last change was an automatic change, false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the last change was automatic.

### getAdjacentBlockClientId

Returns the client ID of the block adjacent one at the given reference
startClientId and modifier directionality. Defaults start startClientId to
the selected block, and direction as next block. Returns null if there is no
adjacent block.

_Parameters_

-   _state_ `Object`: Editor state.
-   _startClientId_ `?string`: Optional client ID of block from which to search.
-   _modifier_ `?number`: Directionality multiplier (1 next, -1 previous).

_Returns_

-   `?string`: Return the client ID of the block, or null if none exists.

### getBlock

Returns a block given its client ID. This is a parsed copy of the block,
containing its `blockName`, `clientId`, and current `attributes` state. This
is not the block's registration settings, which must be retrieved from the
blocks module registration store.

getBlock recurses through its inner blocks until all its children blocks have
been retrieved. Note that getBlock will not return the child inner blocks of
an inner block controller. This is because an inner block controller syncs
itself with its own entity, and should therefore not be included with the
blocks of a different entity. For example, say you call `getBlocks( TP )` to
get the blocks of a template part. If another template part is a child of TP,
then the nested template part's child blocks will not be returned. This way,
the template block itself is considered part of the parent, but the children
are not.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `Object`: Parsed block object.

### getBlockAttributes

Returns a block's attributes given its client ID, or null if no block exists with
the client ID.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `Object?`: Block attributes.

### getBlockCount

Returns the number of blocks currently present in the post.

_Parameters_

-   _state_ `Object`: Editor state.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `number`: Number of blocks in the post.

### getBlockHierarchyRootClientId

Given a block client ID, returns the root of the hierarchy from which the block is nested, return the block itself for root level blocks.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block from which to find root client ID.

_Returns_

-   `string`: Root client ID

### getBlockIndex

Returns the index at which the block corresponding to the specified client
ID occurs within the block order, or `-1` if the block does not exist.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `number`: Index at which block exists in order.

### getBlockInsertionPoint

Returns the insertion point, the index at which the new inserted block would
be placed. Defaults to the last index.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `Object`: Insertion point object with `rootClientId`, `index`.

### getBlockListSettings

Returns the Block List settings of a block, if any exist.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `?string`: Block client ID.

_Returns_

-   `?Object`: Block settings of the block if set.

### getBlockMode

Returns the block's editing mode, defaulting to "visual" if not explicitly
assigned.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `Object`: Block editing mode.

### getBlockName

Returns a block's name given its client ID, or null if no block exists with
the client ID.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `string`: Block name.

### getBlockOrder

Returns an array containing all block client IDs in the editor in the order
they appear. Optionally accepts a root client ID of the block list for which
the order should be returned, defaulting to the top-level block order.

_Parameters_

-   _state_ `Object`: Editor state.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `Array`: Ordered client IDs of editor blocks.

### getBlockParents

Given a block client ID, returns the list of all its parents from top to bottom.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block from which to find root client ID.
-   _ascending_ `boolean`: Order results from bottom to top (true) or top to bottom (false).

_Returns_

-   `Array`: ClientIDs of the parent blocks.

### getBlockParentsByBlockName

Given a block client ID and a block name, returns the list of all its parents
from top to bottom, filtered by the given name(s). For example, if passed
'core/group' as the blockName, it will only return parents which are group
blocks. If passed `[ 'core/group', 'core/cover']`, as the blockName, it will
return parents which are group blocks and parents which are cover blocks.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block from which to find root client ID.
-   _blockName_ `string|string[]`: Block name(s) to filter.
-   _ascending_ `boolean`: Order results from bottom to top (true) or top to bottom (false).

_Returns_

-   `Array`: ClientIDs of the parent blocks.

### getBlockRootClientId

Given a block client ID, returns the root block from which the block is
nested, an empty string for top-level blocks, or null if the block does not
exist.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block from which to find root client ID.

_Returns_

-   `?string`: Root client ID, if exists

### getBlocks

Returns all block objects for the current post being edited as an array in
the order they appear in the post. Note that this will exclude child blocks
of nested inner block controllers.

_Parameters_

-   _state_ `Object`: Editor state.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `Object[]`: Post blocks.

### getBlocksByClientId

Given an array of block client IDs, returns the corresponding array of block
objects.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientIds_ `string[]`: Client IDs for which blocks are to be returned.

_Returns_

-   `WPBlock[]`: Block objects.

### getBlockSelectionEnd

Returns the current block selection end. This value may be null, and it
may represent either a singular block selection or multi-selection end.
A selection is singular if its start and end match.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?string`: Client ID of block selection end.

### getBlockSelectionStart

Returns the current block selection start. This value may be null, and it
may represent either a singular block selection or multi-selection start.
A selection is singular if its start and end match.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?string`: Client ID of block selection start.

### getBlockTransformItems

Determines the items that appear in the available block transforms list.

Each item object contains what's necessary to display a menu item in the
transform list and handle its selection.

The 'frecency' property is a heuristic (<https://en.wikipedia.org/wiki/Frecency>)
that combines block usage frequenty and recency.

Items are returned ordered descendingly by their 'frecency'.

_Parameters_

-   _state_ `Object`: Editor state.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `WPEditorTransformItem[]`: Items that appear in inserter.

_Type Definition_

-   _WPEditorTransformItem_ `Object`

_Properties_

-   _id_ `string`: Unique identifier for the item.
-   _name_ `string`: The type of block to create.
-   _title_ `string`: Title of the item, as it appears in the inserter.
-   _icon_ `string`: Dashicon for the item, as it appears in the inserter.
-   _isDisabled_ `boolean`: Whether or not the user should be prevented from inserting this item.
-   _frecency_ `number`: Heuristic that combines frequency and recency.

### getClientIdsOfDescendants

Returns an array containing the clientIds of all descendants
of the blocks given.

_Parameters_

-   _state_ `Object`: Global application state.
-   _clientIds_ `Array`: Array of blocks to inspect.

_Returns_

-   `Array`: ids of descendants.

### getClientIdsWithDescendants

Returns an array containing the clientIds of the top-level blocks
and their descendants of any depth (for nested blocks).

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Array`: ids of top-level and descendant blocks.

### getDraggedBlockClientIds

Returns the client ids of any blocks being directly dragged.

This does not include children of a parent being dragged.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `string[]`: Array of dragged block client ids.

### getFirstMultiSelectedBlockClientId

Returns the client ID of the first block in the multi-selection set, or null
if there is no multi-selection.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `?string`: First block client ID in the multi-selection set.

### getGlobalBlockCount

Returns the total number of blocks, or the total number of blocks with a specific name in a post.
The number returned includes nested blocks.

_Parameters_

-   _state_ `Object`: Global application state.
-   _blockName_ `?string`: Optional block name, if specified only blocks of that type will be counted.

_Returns_

-   `number`: Number of blocks in the post, or number of blocks with name equal to blockName.

### getInserterItems

Determines the items that appear in the inserter. Includes both static
items (e.g. a regular block type) and dynamic items (e.g. a reusable block).

Each item object contains what's necessary to display a button in the
inserter and handle its selection.

The 'frecency' property is a heuristic (<https://en.wikipedia.org/wiki/Frecency>)
that combines block usage frequenty and recency.

Items are returned ordered descendingly by their 'utility' and 'frecency'.

_Parameters_

-   _state_ `Object`: Editor state.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `WPEditorInserterItem[]`: Items that appear in inserter.

_Type Definition_

-   _WPEditorInserterItem_ `Object`

_Properties_

-   _id_ `string`: Unique identifier for the item.
-   _name_ `string`: The type of block to create.
-   _initialAttributes_ `Object`: Attributes to pass to the newly created block.
-   _title_ `string`: Title of the item, as it appears in the inserter.
-   _icon_ `string`: Dashicon for the item, as it appears in the inserter.
-   _category_ `string`: Block category that the item is associated with.
-   _keywords_ `string[]`: Keywords that can be searched to find this item.
-   _isDisabled_ `boolean`: Whether or not the user should be prevented from inserting this item.
-   _frecency_ `number`: Heuristic that combines frequency and recency.

### getLastMultiSelectedBlockClientId

Returns the client ID of the last block in the multi-selection set, or null
if there is no multi-selection.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `?string`: Last block client ID in the multi-selection set.

### getLowestCommonAncestorWithSelectedBlock

Given a block client ID, returns the lowest common ancestor with selected client ID.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block from which to find common ancestor client ID.

_Returns_

-   `string`: Common ancestor client ID or undefined

### getMultiSelectedBlockClientIds

Returns the current multi-selection set of block client IDs, or an empty
array if there is no multi-selection.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `Array`: Multi-selected block client IDs.

### getMultiSelectedBlocks

Returns the current multi-selection set of blocks, or an empty array if
there is no multi-selection.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `Array`: Multi-selected block objects.

### getMultiSelectedBlocksEndClientId

Returns the client ID of the block which ends the multi-selection set, or
null if there is no multi-selection.

This is not necessarily the last client ID in the selection.

_Related_

-   getLastMultiSelectedBlockClientId

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `?string`: Client ID of block ending multi-selection.

### getMultiSelectedBlocksStartClientId

Returns the client ID of the block which begins the multi-selection set, or
null if there is no multi-selection.

This is not necessarily the first client ID in the selection.

_Related_

-   getFirstMultiSelectedBlockClientId

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `?string`: Client ID of block beginning multi-selection.

### getNextBlockClientId

Returns the next block's client ID from the given reference start ID.
Defaults start to the selected block. Returns null if there is no next
block.

_Parameters_

-   _state_ `Object`: Editor state.
-   _startClientId_ `?string`: Optional client ID of block from which to search.

_Returns_

-   `?string`: Adjacent block's client ID, or null if none exists.

### getPreviousBlockClientId

Returns the previous block's client ID from the given reference start ID.
Defaults start to the selected block. Returns null if there is no previous
block.

_Parameters_

-   _state_ `Object`: Editor state.
-   _startClientId_ `?string`: Optional client ID of block from which to search.

_Returns_

-   `?string`: Adjacent block's client ID, or null if none exists.

### getSelectedBlock

Returns the currently selected block, or null if there is no selected block.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?Object`: Selected block.

### getSelectedBlockClientId

Returns the currently selected block client ID, or null if there is no
selected block.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `?string`: Selected block client ID.

### getSelectedBlockClientIds

Returns the current selection set of block client IDs (multiselection or single selection).

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `Array`: Multi-selected block client IDs.

### getSelectedBlockCount

Returns the number of blocks currently selected in the post.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `number`: Number of blocks selected in the post.

### getSelectedBlocksInitialCaretPosition

Returns the initial caret position for the selected block.
This position is to used to position the caret properly when the selected block changes.
If the current block is not a RichText, having initial position set to 0 means "focus block"

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `0|-1|null`: Initial position.

### getSelectionEnd

Returns the current selection end block client ID, attribute key and text
offset.

_Parameters_

-   _state_ `Object`: Block editor state.

_Returns_

-   `WPBlockSelection`: Selection end information.

### getSelectionStart

Returns the current selection start block client ID, attribute key and text
offset.

_Parameters_

-   _state_ `Object`: Block editor state.

_Returns_

-   `WPBlockSelection`: Selection start information.

### getSettings

Returns the editor settings.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `Object`: The editor settings object.

### getTemplate

Returns the defined block template

_Parameters_

-   _state_ `boolean`:

_Returns_

-   `?Array`: Block Template.

### getTemplateLock

Returns the defined block template lock. Optionally accepts a root block
client ID as context, otherwise defaulting to the global context.

_Parameters_

-   _state_ `Object`: Editor state.
-   _rootClientId_ `?string`: Optional block root client ID.

_Returns_

-   `?string`: Block Template Lock

### hasBlockMovingClientId

Returns whether block moving mode is enabled.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `string`: Client Id of moving block.

### hasInserterItems

Determines whether there are items to show in the inserter.

_Parameters_

-   _state_ `Object`: Editor state.
-   _rootClientId_ `?string`: Optional root client ID of block list.

_Returns_

-   `boolean`: Items that appear in inserter.

### hasMultiSelection

Returns true if a multi-selection has been made, or false otherwise.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `boolean`: Whether multi-selection has been made.

### hasSelectedBlock

Returns true if there is a single selected block, or false otherwise.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `boolean`: Whether a single block is selected.

### hasSelectedInnerBlock

Returns true if one of the block's inner blocks is selected.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.
-   _deep_ `boolean`: Perform a deep check.

_Returns_

-   `boolean`: Whether the block as an inner block selected

### isAncestorBeingDragged

Returns whether a parent/ancestor of the block is being dragged.

_Parameters_

-   _state_ `Object`: Global application state.
-   _clientId_ `string`: Client id for block to check.

_Returns_

-   `boolean`: Whether the block's ancestor is being dragged.

### isAncestorMultiSelected

Returns true if an ancestor of the block is multi-selected, or false
otherwise.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `boolean`: Whether an ancestor of the block is in multi-selection set.

### isBlockBeingDragged

Returns whether the block is being dragged.

Only returns true if the block is being directly dragged,
not if the block is a child of a parent being dragged.
See `isAncestorBeingDragged` for child blocks.

_Parameters_

-   _state_ `Object`: Global application state.
-   _clientId_ `string`: Client id for block to check.

_Returns_

-   `boolean`: Whether the block is being dragged.

### isBlockHighlighted

Returns true if the current highlighted block matches the block clientId.

_Parameters_

-   _state_ `Object`: Global application state.
-   _clientId_ `string`: The block to check.

_Returns_

-   `boolean`: Whether the block is currently highlighted.

### isBlockInsertionPointVisible

Returns true if we should show the block insertion point.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?boolean`: Whether the insertion point is visible or not.

### isBlockMultiSelected

Returns true if the client ID occurs within the block multi-selection, or
false otherwise.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `boolean`: Whether block is in multi-selection set.

### isBlockSelected

Returns true if the block corresponding to the specified client ID is
currently selected and no multi-selection exists, or false otherwise.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `boolean`: Whether block is selected and multi-selection exists.

### isBlockValid

Returns whether a block is valid or not.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `boolean`: Is Valid.

### isBlockWithinSelection

Returns true if the block corresponding to the specified client ID is
currently selected but isn't the last of the selected blocks. Here "last"
refers to the block sequence in the document, _not_ the sequence of
multi-selection, which is why `state.selectionEnd` isn't used.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `boolean`: Whether block is selected and not the last in the selection.

### isCaretWithinFormattedText

Returns true if the caret is within formatted text, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the caret is within formatted text.

### isDraggingBlocks

Returns true if the user is dragging blocks, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether user is dragging blocks.

### isFirstMultiSelectedBlock

Returns true if a multi-selection exists, and the block corresponding to the
specified client ID is the first block of the multi-selection set, or false
otherwise.

_Parameters_

-   _state_ `Object`: Editor state.
-   _clientId_ `string`: Block client ID.

_Returns_

-   `boolean`: Whether block is first in multi-selection.

### isLastBlockChangePersistent

Returns true if the most recent block change is be considered persistent, or
false otherwise. A persistent change is one committed by BlockEditorProvider
via its `onChange` callback, in addition to `onInput`.

_Parameters_

-   _state_ `Object`: Block editor state.

_Returns_

-   `boolean`: Whether the most recent block change was persistent.

### isMultiSelecting

Whether in the process of multi-selecting or not. This flag is only true
while the multi-selection is being selected (by mouse move), and is false
once the multi-selection has been settled.

_Related_

-   hasMultiSelection

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: True if multi-selecting, false if not.

### isNavigationMode

Returns whether the navigation mode is enabled.

_Parameters_

-   _state_ `Object`: Editor state.

_Returns_

-   `boolean`: Is navigation mode enabled.

### isSelectionEnabled

Selector that returns if multi-selection is enabled or not.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: True if it should be possible to multi-select blocks, false if multi-selection is disabled.

### isTyping

Returns true if the user is typing, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether user is typing.

### isValidTemplate

Returns whether the blocks matches the template or not.

_Parameters_

-   _state_ `boolean`:

_Returns_

-   `?boolean`: Whether the template is valid or not.

### wasBlockJustInserted

Tells if the block with the passed clientId was just inserted.

_Parameters_

-   _state_ `Object`: Global application state.
-   _clientId_ `Object`: Client Id of the block.
-   _source_ `?string`: Optional insertion source of the block.

_Returns_

-   `boolean`: True if the block matches the last block inserted from the specified source.

<!-- END TOKEN(Autogenerated selectors|../../../packages/block-editor/src/store/selectors.js) -->

## Actions

<!-- START TOKEN(Autogenerated actions|../../../packages/block-editor/src/store/actions.js) -->

### clearSelectedBlock

Action that clears the block selection.

_Returns_

-   `Object`: Action object.

### duplicateBlocks

Action that duplicates a list of blocks.

_Parameters_

-   _clientIds_ `string[]`:
-   _updateSelection_ `boolean`:

### enterFormattedText

Returns an action object used in signalling that the caret has entered formatted text.

_Returns_

-   `Object`: Action object.

### exitFormattedText

Returns an action object used in signalling that the user caret has exited formatted text.

_Returns_

-   `Object`: Action object.

### flashBlock

Action that "flashes" the block with a given `clientId` by rhythmically highlighting it.

_Parameters_

-   _clientId_ `string`: Target block client ID.

### hideInsertionPoint

Action that hides the insertion point.

_Returns_

-   `Object`: Action object.

### insertAfterBlock

Action that inserts an empty block after a given block.

_Parameters_

-   _clientId_ `string`:

### insertBeforeBlock

Action that inserts an empty block before a given block.

_Parameters_

-   _clientId_ `string`:

### insertBlock

Action that inserts a single block, optionally at a specific index respective a root block list.

_Parameters_

-   _block_ `Object`: Block object to insert.
-   _index_ `?number`: Index at which block should be inserted.
-   _rootClientId_ `?string`: Optional root client ID of block list on which to insert.
-   _updateSelection_ `?boolean`: If true block selection will be updated. If false, block selection will not change. Defaults to true.
-   _meta_ `?Object`: Optional Meta values to be passed to the action object.

_Returns_

-   `Object`: Action object.

### insertBlocks

Action that inserts an array of blocks, optionally at a specific index respective a root block list.

_Parameters_

-   _blocks_ `Object[]`: Block objects to insert.
-   _index_ `?number`: Index at which block should be inserted.
-   _rootClientId_ `?string`: Optional root client ID of block list on which to insert.
-   _updateSelection_ `?boolean`: If true block selection will be updated. If false, block selection will not change. Defaults to true.
-   _initialPosition_ `0|-1|null`: Initial focus position. Setting it to null prevent focusing the inserted block.
-   _meta_ `?Object`: Optional Meta values to be passed to the action object.

_Returns_

-   `Object`: Action object.

### insertDefaultBlock

Action that adds a new block of the default type to the block list.

_Parameters_

-   _attributes_ `?Object`: Optional attributes of the block to assign.
-   _rootClientId_ `?string`: Optional root client ID of block list on which to append.
-   _index_ `?number`: Optional index where to insert the default block

_Returns_

-   `Object`: Action object

### mergeBlocks

Action that merges two blocks.

_Parameters_

-   _firstBlockClientId_ `string`: Client ID of the first block to merge.
-   _secondBlockClientId_ `string`: Client ID of the second block to merge.

### moveBlocksDown

Undocumented declaration.

### moveBlocksToPosition

Action that moves given blocks to a new position.

_Parameters_

-   _clientIds_ `?string`: The client IDs of the blocks.
-   _fromRootClientId_ `?string`: Root client ID source.
-   _toRootClientId_ `?string`: Root client ID destination.
-   _index_ `number`: The index to move the blocks to.

### moveBlocksUp

Undocumented declaration.

### moveBlockToPosition

Action that moves given block to a new position.

_Parameters_

-   _clientId_ `?string`: The client ID of the block.
-   _fromRootClientId_ `?string`: Root client ID source.
-   _toRootClientId_ `?string`: Root client ID destination.
-   _index_ `number`: The index to move the block to.

### multiSelect

Action that changes block multi-selection.

_Parameters_

-   _start_ `string`: First block of the multi selection.
-   _end_ `string`: Last block of the multiselection.

### receiveBlocks

> **Deprecated**

Returns an action object used in signalling that blocks have been received.
Unlike resetBlocks, these should be appended to the existing known set, not
replacing.

_Parameters_

-   _blocks_ `Object[]`: Array of block objects.

_Returns_

-   `Object`: Action object.

### removeBlock

Returns an action object used in signalling that the block with the
specified client ID is to be removed.

_Parameters_

-   _clientId_ `string`: Client ID of block to remove.
-   _selectPrevious_ `boolean`: True if the previous block should be selected when a block is removed.

_Returns_

-   `Object`: Action object.

### removeBlocks

Yields action objects used in signalling that the blocks corresponding to
the set of specified client IDs are to be removed.

_Parameters_

-   _clientIds_ `string|string[]`: Client IDs of blocks to remove.
-   _selectPrevious_ `boolean`: True if the previous block should be selected when a block is removed.

### replaceBlock

Action that replaces a single block with one or more replacement blocks.

_Parameters_

-   _clientId_ `(string|string[])`: Block client ID to replace.
-   _block_ `(Object|Object[])`: Replacement block(s).

_Returns_

-   `Object`: Action object.

### replaceBlocks

Action that replaces given blocks with one or more replacement blocks.

_Parameters_

-   _clientIds_ `(string|string[])`: Block client ID(s) to replace.
-   _blocks_ `(Object|Object[])`: Replacement block(s).
-   _indexToSelect_ `number`: Index of replacement block to select.
-   _initialPosition_ `0|-1|null`: Index of caret after in the selected block after the operation.
-   _meta_ `?Object`: Optional Meta values to be passed to the action object.

_Returns_

-   `Object`: Action object.

### replaceInnerBlocks

Returns an action object used in signalling that the inner blocks with the
specified client ID should be replaced.

_Parameters_

-   _rootClientId_ `string`: Client ID of the block whose InnerBlocks will re replaced.
-   _blocks_ `Object[]`: Block objects to insert as new InnerBlocks
-   _updateSelection_ `?boolean`: If true block selection will be updated. If false, block selection will not change. Defaults to false.
-   _initialPosition_ `0|-1|null`: Initial block position.

_Returns_

-   `Object`: Action object.

### resetBlocks

Action that resets blocks state to the specified array of blocks, taking precedence
over any other content reflected as an edit in state.

_Parameters_

-   _blocks_ `Array`: Array of blocks.

### resetSelection

Returns an action object used in signalling that selection state should be
reset to the specified selection.

_Parameters_

-   _selectionStart_ `WPBlockSelection`: The selection start.
-   _selectionEnd_ `WPBlockSelection`: The selection end.
-   _initialPosition_ `0|-1|null`: Initial block position.

_Returns_

-   `Object`: Action object.

### selectBlock

Returns an action object used in signalling that the block with the
specified client ID has been selected, optionally accepting a position
value reflecting its selection directionality. An initialPosition of -1
reflects a reverse selection.

_Parameters_

-   _clientId_ `string`: Block client ID.
-   _initialPosition_ `0|-1|null`: Optional initial position. Pass as -1 to reflect reverse selection.

_Returns_

-   `Object`: Action object.

### selectionChange

Action that changes the position of the user caret.

_Parameters_

-   _clientId_ `string`: The selected block client ID.
-   _attributeKey_ `string`: The selected block attribute key.
-   _startOffset_ `number`: The start offset.
-   _endOffset_ `number`: The end offset.

_Returns_

-   `Object`: Action object.

### selectNextBlock

Yields action objects used in signalling that the block following the given
clientId should be selected.

_Parameters_

-   _clientId_ `string`: Block client ID.

### selectPreviousBlock

Yields action objects used in signalling that the block preceding the given
clientId should be selected.

_Parameters_

-   _clientId_ `string`: Block client ID.

### setBlockMovingClientId

Action that enables or disables the block moving mode.

_Parameters_

-   _hasBlockMovingClientId_ `string|null`: Enable/Disable block moving mode.

### setHasControlledInnerBlocks

Action that sets whether a block has controlled inner blocks.

_Parameters_

-   _clientId_ `string`: The block's clientId.
-   _hasControlledInnerBlocks_ `boolean`: True if the block's inner blocks are controlled.

### setNavigationMode

Action that enables or disables the navigation mode.

_Parameters_

-   _isNavigationMode_ `string`: Enable/Disable navigation mode.

### setTemplateValidity

Action that resets the template validity.

_Parameters_

-   _isValid_ `boolean`: template validity flag.

_Returns_

-   `Object`: Action object.

### showInsertionPoint

Action that shows the insertion point.

_Parameters_

-   _rootClientId_ `?string`: Optional root client ID of block list on which to insert.
-   _index_ `?number`: Index at which block should be inserted.
-   _\_\_unstableOptions_ `Object`: Wether or not to show an inserter button.

_Returns_

-   `Object`: Action object.

### startDraggingBlocks

Returns an action object used in signalling that the user has begun to drag blocks.

_Parameters_

-   _clientIds_ `string[]`: An array of client ids being dragged

_Returns_

-   `Object`: Action object.

### startMultiSelect

Action that starts block multi-selection.

_Returns_

-   `Object`: Action object.

### startTyping

Returns an action object used in signalling that the user has begun to type.

_Returns_

-   `Object`: Action object.

### stopDraggingBlocks

Returns an action object used in signalling that the user has stopped dragging blocks.

_Returns_

-   `Object`: Action object.

### stopMultiSelect

Action that stops block multi-selection.

_Returns_

-   `Object`: Action object.

### stopTyping

Returns an action object used in signalling that the user has stopped typing.

_Returns_

-   `Object`: Action object.

### synchronizeTemplate

Action that synchronizes the template with the list of blocks.

_Returns_

-   `Object`: Action object.

### toggleBlockHighlight

Action that toggles the highlighted block state.

_Parameters_

-   _clientId_ `string`: The block's clientId.
-   _isHighlighted_ `boolean`: The highlight state.

### toggleBlockMode

Returns an action object used to toggle the block editing mode between
visual and HTML modes.

_Parameters_

-   _clientId_ `string`: Block client ID.

_Returns_

-   `Object`: Action object.

### toggleSelection

Action that enables or disables block selection.

_Parameters_

-   _isSelectionEnabled_ `[boolean]`: Whether block selection should be enabled.

_Returns_

-   `Object`: Action object.

### updateBlock

Action that updates the block with the specified client ID.

_Parameters_

-   _clientId_ `string`: Block client ID.
-   _updates_ `Object`: Block attributes to be merged.

_Returns_

-   `Object`: Action object.

### updateBlockAttributes

Action that updates attributes of multiple blocks with the specified client IDs.

_Parameters_

-   _clientIds_ `string|string[]`: Block client IDs.
-   _attributes_ `Object`: Block attributes to be merged. Should be keyed by clientIds if uniqueByBlock is true.
-   _uniqueByBlock_ `boolean`: true if each block in clientIds array has a unique set of attributes

_Returns_

-   `Object`: Action object.

### updateBlockListSettings

Action that changes the nested settings of a given block.

_Parameters_

-   _clientId_ `string`: Client ID of the block whose nested setting are being received.
-   _settings_ `Object`: Object with the new settings for the nested block.

_Returns_

-   `Object`: Action object

### updateSettings

Action that updates the block editor settings.

_Parameters_

-   _settings_ `Object`: Updated settings

_Returns_

-   `Object`: Action object

### validateBlocksToTemplate

Block validity is a function of blocks state (at the point of a
reset) and the template setting. As a compromise to its placement
across distinct parts of state, it is implemented here as a side-
effect of the block reset action.

_Parameters_

-   _blocks_ `Array`: Array of blocks.

<!-- END TOKEN(Autogenerated actions|../../../packages/block-editor/src/store/actions.js) -->
