# Notices Data

Namespace: `core/notices`.

## Selectors

<!-- START TOKEN(Autogenerated selectors|../../../packages/notices/src/store/selectors.js) -->

### getNotices

Returns all notices as an array, optionally for a given context. Defaults to
the global context.

_Parameters_

-   _state_ `Object`: Notices state.
-   _context_ `?string`: Optional grouping context.

_Returns_

-   `WPNotice[]`: Array of notices.

<!-- END TOKEN(Autogenerated selectors|../../../packages/notices/src/store/selectors.js) -->

## Actions

<!-- START TOKEN(Autogenerated actions|../../../packages/notices/src/store/actions.js) -->

### createErrorNotice

Returns an action object used in signalling that an error notice is to be
created. Refer to `createNotice` for options documentation.

_Related_

-   createNotice

_Parameters_

-   _content_ `string`: Notice message.
-   _options_ `[Object]`: Optional notice options.

_Returns_

-   `Object`: Action object.

### createInfoNotice

Returns an action object used in signalling that an info notice is to be
created. Refer to `createNotice` for options documentation.

_Related_

-   createNotice

_Parameters_

-   _content_ `string`: Notice message.
-   _options_ `[Object]`: Optional notice options.

_Returns_

-   `Object`: Action object.

### createNotice

Returns an action object used in signalling that a notice is to be created.

_Parameters_

-   _status_ `[string]`: Notice status.
-   _content_ `string`: Notice message.
-   _options_ `[Object]`: Notice options.
-   _options.context_ `[string]`: Context under which to group notice.
-   _options.id_ `[string]`: Identifier for notice. Automatically assigned if not specified.
-   _options.isDismissible_ `[boolean]`: Whether the notice can be dismissed by user.
-   _options.type_ `[string]`: Type of notice, one of `default`, or `snackbar`.
-   _options.speak_ `[boolean]`: Whether the notice content should be announced to screen readers.
-   _options.actions_ `[Array<WPNoticeAction>]`: User actions to be presented with notice.
-   _options.icon_ `[Object]`: An icon displayed with the notice.
-   _options.explicitDismiss_ `[boolean]`: Whether the notice includes an explict dismiss button and can't be dismissed by clicking the body of the notice.
-   _options.onDismiss_ `[Function]`: Called when the notice is dismissed.

_Returns_

-   `Object`: Action object.

### createSuccessNotice

Returns an action object used in signalling that a success notice is to be
created. Refer to `createNotice` for options documentation.

_Related_

-   createNotice

_Parameters_

-   _content_ `string`: Notice message.
-   _options_ `[Object]`: Optional notice options.

_Returns_

-   `Object`: Action object.

### createWarningNotice

Returns an action object used in signalling that a warning notice is to be
created. Refer to `createNotice` for options documentation.

_Related_

-   createNotice

_Parameters_

-   _content_ `string`: Notice message.
-   _options_ `[Object]`: Optional notice options.

_Returns_

-   `Object`: Action object.

### removeNotice

Returns an action object used in signalling that a notice is to be removed.

_Parameters_

-   _id_ `string`: Notice unique identifier.
-   _context_ `[string]`: Optional context (grouping) in which the notice is intended to appear. Defaults to default context.

_Returns_

-   `Object`: Action object.

<!-- END TOKEN(Autogenerated actions|../../../packages/notices/src/store/actions.js) -->
